==> release.12.2.28.1.tgz: cgi-cpn/dam/prontus_dam_ppart_delete.pl <==
#!/usr/bin/perl

# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------

# -------------------------------COMENTARIO GLOBAL---------------
# ---------------------------------------------------------------
# PROPOSITO.
# -----------
# Elimina los archivos, en tabla ASSET, asociados a un articulo eliminado
# ---------------------------------------------------------------
#
# -------------------------------BEGIN LIBRERIA------------------
# ---------------------------------------------------------------
# DECLARACIONES GLOBALES.
# ------------------------
use strict;
use utf8;

BEGIN {
    use FindBin qw($Bin);
    my $pathLibsProntus = $Bin;
    unshift(@INC,$pathLibsProntus);

    $pathLibsProntus =~ s/\/[^\/]+\/?$//;
    unshift(@INC,$pathLibsProntus);
}

##libs##
use lib_stdlog;
lib_stdlog::set_stdlog($0, 51200);
use prontus_varglb;
prontus_varglb::init();

use DBI;
use File::Copy;
use glib_dbi_03;
use glib_fildir_03;
use lib_bd;
use lib_utils;
##/libs##

close STDOUT;

main:{
    lib_utils::setUtf8();
    # Carga archivo de configuracion
    my $ts = $ARGV[0];
    $prontus_varglb::PRONTUS_ID = $ARGV[1];

    if (scalar @ARGV < 2) {
        print "Parametros insuficientes Terminando\n";
        exit;
    }

    # valida el identificador de prontus
    if ($prontus_varglb::PRONTUS_ID eq '' || !lib_utils::valida_prontus($prontus_varglb::PRONTUS_ID)) {
        print "El identificador de Prontus es inválido\n";
        exit;
    }

    my $msg_load = lib_utils::load_config_by_id($prontus_varglb::PRONTUS_ID);
    if ($msg_load ne '') {
        print "Ha ocurrido un error: $msg_load\n";
        exit;
    }

    # Inicia conexion a BD
    my ($base, $msg_err_bd) = lib_bd::conectar_prontus_bd();
    if (!ref($base)) {
        print STDERR "Hubo problemas para conetarse a la BD: [$msg_err_bd]";
        exit;
    }

    # Elimina los archivos de ese TS
    if ($ts =~ /^\d{14}$/i) {
        my @params = ($ts);
        my $sql = 'DELETE FROM ASSET WHERE ASSET_ART_ID = ?';

        my $salida = glib_dbi_03::ejecutar_sql_param($base, $sql, \@params);
        if ($base->errstr) {
            print STDERR $base->errstr;
            exit;
        }
    } else {
        print STDERR "TS no es valido";
        exit;
    }
};

==> release.12.3.1.2.tgz: cgi-cpn/dam/prontus_dam_ppart_delete.pl <==
#!/usr/bin/perl

# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------

# -------------------------------COMENTARIO GLOBAL---------------
# ---------------------------------------------------------------
# PROPOSITO.
# -----------
# Elimina los archivos, en tabla asset, asociados a un articulo eliminado
# ---------------------------------------------------------------
#
# -------------------------------BEGIN LIBRERIA------------------
# ---------------------------------------------------------------
# DECLARACIONES GLOBALES.
# ------------------------
use strict;
use utf8;

BEGIN {
    use FindBin qw($Bin);
    my $pathLibsProntus = $Bin;
    unshift(@INC,$pathLibsProntus);

    $pathLibsProntus =~ s/\/[^\/]+\/?$//;
    unshift(@INC,$pathLibsProntus);
}

##libs##
use lib_stdlog;
lib_stdlog::set_stdlog($0, 51200);
use prontus_varglb;
prontus_varglb::init();

use DBI;
use File::Copy;
use JSON;
use glib_dbi_03;
use glib_fildir_03;
use lib_bd;
use lib_lang;
use lib_utils;
##/libs##

close STDOUT;

main:{
    lib_utils::setUp();
    # Carga archivo de configuracion
    my $ts = $ARGV[0];
    my $prontus_id = $ARGV[1];

    if (scalar @ARGV < 2) {
        print lib_lang::get_message('global_use_instructions');
        print "perl $0 <timestamp> <prontus_id>\n";
        exit;
    }

    my $msg_load = lib_utils::load_config_by_id($prontus_id);
    if ($msg_load ne '') {
        print "$msg_load\n";
        exit;
    }

    # Inicia conexion a BD
    my ($base, $msg_err_bd) = lib_bd::conectar_prontus_bd();
    if (!ref($base)) {
        print STDERR $msg_err_bd , "\n";
        exit;
    }

    # Elimina los archivos de ese TS
    if ($ts =~ /^\d{14}$/i) {
        my @params = ($ts);
        my $asset_table = lib_utils::get_table('asset');
        my $sql = "delete from $asset_table where asset_art_id = ?";

        my $salida = glib_dbi_03::ejecutar_sql_param($base, $sql, \@params);
        if ($base->errstr) {
            print STDERR $base->errstr;
            exit;
        }
    } else {
        print STDERR lib_lang::get_message('global_invalid_ts') , "\n";
        exit;
    }
}
